hotspot/src/cpu/x86/vm/templateTable_x86_32.cpp
changeset 8883 5569135acca3
parent 8882 f852635a6383
child 9179 6db9c9dffe1f
child 9324 c2e97d1d66d2
--- a/hotspot/src/cpu/x86/vm/templateTable_x86_32.cpp	Thu Mar 31 00:27:08 2011 -0700
+++ b/hotspot/src/cpu/x86/vm/templateTable_x86_32.cpp	Thu Mar 31 02:31:57 2011 -0700
@@ -392,8 +392,8 @@
 void TemplateTable::fast_aldc(bool wide) {
   transition(vtos, atos);
 
-  if (!EnableMethodHandles) {
-    // We should not encounter this bytecode if !EnableMethodHandles.
+  if (!EnableInvokeDynamic) {
+    // We should not encounter this bytecode if !EnableInvokeDynamic.
     // The verifier will stop it.  However, if we get past the verifier,
     // this will stop the thread in a reasonable way, without crashing the JVM.
     __ call_VM(noreg, CAST_FROM_FN_PTR(address,